@@ -1,17 +1,7 @@
 # From Hmisc package
 
-##' ascii method for class describe.sing
-##'
-##' \code{Hmisc} package
-##' @param x An R object of class found among \code{methods(ascii)}.
-##' @param condense default is TRUE to condense the output with regard to the 5
-##'   lowest and highest values and the frequency table (\code{describe()} in
-##'   package \code{Hmisc}).
-##' @param ... Additional arguments.  (see \code{?ascii.default}).
-##' @return An ascii object.
 ##' @export
 ##' @method ascii describe.single
-##' @author David Hajage
 ascii.describe.single <- function (x, condense = TRUE, ...) {
    wide <- .Options$width
     # des : le titre
@@ -83,23 +73,16 @@ ascii.describe.single <- function (x, condense = TRUE, ...) {
 #   if (length(x$mChoice)) {
 #       print(x$mChoice, prlabel = FALSE)
 #   }
-  res <- asciiMixed$new(counts, val)
-  class(res) <- c("ascii", "proto", "environment")
+  res <- asciiMixed$new(args = list(counts, val))
   return(res)
 }
 
-##' ascii method fo class describe
-##'
-##' \code{Hmisc} package
-##' @param x An R object of class found among \code{methods(ascii)}.
 ##' @param condense default is TRUE to condense the output with regard to the 5
 ##'   lowest and highest values and the frequency table (\code{describe()} in
 ##'   package \code{Hmisc}).
-##' @param ... Additional arguments.  (see \code{?ascii.default}).
-##' @return An ascii object.
 ##' @export
 ##' @method ascii describe
-##' @author David Hajage
+##' @rdname ascii
 ascii.describe <- function (x, condense = TRUE, ...) {
   at <- attributes(x)
   descrip <- ifelse(is.null(at$descript), "", at$descrip)
@@ -121,15 +104,13 @@ ascii.describe <- function (x, condense = TRUE, ...) {
         res <- NULL
         for (z in 1:length(x)) {
           if (length(x[[z]]) == 0) next
-          res <- asciiMixed$new(res, xx[[z]])
-          class(res) <- c("ascii", "proto", "environment")
+          res <- asciiMixed$new(args = list(res, xx[[z]]))
         }
     }
     else res <- ascii.describe.single(x, condense = condense)
 
-  if (length(at$naprint)) { na <- ascii(as.list(at$naprint)) ; res <- asciiMixed$new(des, na, res) }
-  else res <- asciiMixed$new(des, res)
-  class(res) <- c("ascii", "proto", "environment")
+  if (length(at$naprint)) { na <- ascii(as.list(at$naprint)) ; res <- asciiMixed$new(args = list(des, na, res)) }
+  else res <- asciiMixed$new(args = list(des, res))
 
   return(res)
 }
